@@ -1,6 +1,6 @@
 package WWW::Curl::Simple::Request;
 {
-  $WWW::Curl::Simple::Request::VERSION = '0.100188';
+  $WWW::Curl::Simple::Request::VERSION = '0.100189';
 }
 # ABSTRACT: A small class representing request/response
 
@@ -77,7 +77,7 @@ sub _build_easy {
     # follow redirects for up to 5 hops
     if ($WWW::Curl::Easy::CURLPROTO_HTTP) {
         # This option and the CURLPROTO_HTTP was both added in 7.19.4
-        $curl->setopt(CURLOPT_REDIR_PROTOCOLS, CURLPROTO_HTTP);
+        $curl->setopt($WWW::Curl::Easy::CURLOPT_REDIR_PROTOCOLS, $WWW::Curl::Easy::CURLPROTO_HTTP);
     }
     $curl->setopt(CURLOPT_FOLLOWLOCATION, $max_redirects > 0);
     $curl->setopt(CURLOPT_MAXREDIRS, $max_redirects);
@@ -133,7 +133,7 @@ WWW::Curl::Simple::Request - A small class representing request/response
 
 =head1 VERSION
 
-version 0.100188
+version 0.100189
 
 =head1 DESCRIPTION
 
